==> nemo_library-1.3.5.tar.gz: nemo_library-1.3.5/nemo_library/model/pages.py <==
from dataclasses import dataclass, asdict
from typing import Dict, List

@dataclass
class Visual:
    """
    Represents a visual element on a page.

    Attributes:
        column (int): The column position of the visual.
        columnSpan (int): The number of columns the visual spans.
        content (str): The content of the visual.
        contentTranslations (Dict[str, str]): Translations of the content.
        id (str): The unique identifier of the visual.
        row (int): The row position of the visual.
        rowSpan (int): The number of rows the visual spans.
        type (str): The type of the visual.
    """
    column: int
    columnSpan: int
    content: str
    contentTranslations: Dict[str, str]
    id: str
    row: int
    rowSpan: int
    type: str

@dataclass
class Page:
    """
    Represents a page containing multiple visuals.

    Attributes:
        description (str): The description of the page.
        descriptionTranslations (Dict[str, str]): Translations of the description.
        displayName (str): The display name of the page.
        displayNameTranslations (Dict[str, str]): Translations of the display name.
        hideIfColumns (List[str]): Columns that hide the page if present.
        internalName (str): The internal name of the page.
        numberOfColumns (int): The number of columns on the page.
        numberOfRows (int): The number of rows on the page.
        showIfColumns (List[str]): Columns that show the page if present.
        visuals (List[Visual]): The visuals contained in the page.
        id (str): The unique identifier of the page.
        projectId (str): The project identifier the page belongs to.
        tenant (str): The tenant identifier the page belongs to.
    """
    description: str
    descriptionTranslations: Dict[str, str]
    displayName: str
    displayNameTranslations: Dict[str, str]
    hideIfColumns: List[str]
    internalName: str
    numberOfColumns: int
    numberOfRows: int
    showIfColumns: List[str]
    visuals: List[Visual]
    id: str
    projectId: str
    tenant: str

    def to_dict(self):
        """
        Converts the Page instance to a dictionary.

        Returns:
            dict: A dictionary representation of the Page instance.
        """
        return asdict(self)

==> nemo_library-1.6.25.tar.gz: nemo_library-1.6.25/nemo_library/model/pages.py <==
from dataclasses import dataclass, asdict


@dataclass
class Visual:
    """
    Represents a visual element on a page.

    Attributes:
        column (int): The column position of the visual.
        columnSpan (int): The number of columns the visual spans.
        content (str): The content of the visual.
        contentTranslations (dict[str, str]): Translations of the content.
        id (str): The unique identifier of the visual.
        row (int): The row position of the visual.
        rowSpan (int): The number of rows the visual spans.
        type (str): The type of the visual.
    """

    column: int
    columnSpan: int
    content: str
    contentTranslations: dict[str, str]
    id: str
    row: int
    rowSpan: int
    type: str


@dataclass
class Page:
    """
    Represents a page containing multiple visuals.

    Attributes:
        description (str): The description of the page.
        descriptionTranslations (dict[str, str]): Translations of the description.
        displayName (str): The display name of the page.
        displayNameTranslations (dict[str, str]): Translations of the display name.
        hideIfColumns (list[str]): Columns that hide the page if present.
        internalName (str): The internal name of the page.
        numberOfColumns (int): The number of columns on the page.
        numberOfRows (int): The number of rows on the page.
        showIfColumns (list[str]): Columns that show the page if present.
        visuals (list[Visual]): The visuals contained in the page.
        id (str): The unique identifier of the page.
        projectId (str): The project identifier the page belongs to.
        tenant (str): The tenant identifier the page belongs to.
    """

    description: str
    descriptionTranslations: dict[str, str]
    displayName: str
    displayNameTranslations: dict[str, str]
    hideIfColumns: list[str]
    internalName: str
    numberOfColumns: int
    numberOfRows: int
    showIfColumns: list[str]
    visuals: list[Visual]
    id: str
    projectId: str
    tenant: str
    isCustom: bool = False
    metadataClassificationInternalName: str = ""

    def to_dict(self):
        """
        Converts the Page instance to a dictionary.

        Returns:
            dict: A dictionary representation of the Page instance.
        """
        return asdict(self)
